/// @cond EO_CXX_EO_IMPL

inline void evas_3d_camera::projection_matrix_set(const Evas_Real * matrix_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_camera_projection_matrix_set(matrix_));
}

inline void evas_3d_camera::projection_matrix_get(Evas_Real* matrix_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_camera_projection_matrix_get(matrix_));
}

inline void evas_3d_camera::projection_perspective_set(Evas_Real fovy_, Evas_Real aspect_, Evas_Real dnear_, Evas_Real dfar_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_camera_projection_perspective_set(fovy_, aspect_, dnear_, dfar_));
}

inline void evas_3d_camera::projection_frustum_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_camera_projection_frustum_set(left_, right_, bottom_, top_, dnear_, dfar_));
}

inline void evas_3d_camera::projection_ortho_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_camera_projection_ortho_set(left_, right_, bottom_, top_, dnear_, dfar_));
}

inline bool evas_3d_camera::node_visible_get(Evas_3D_Node * camera_node_, Evas_3D_Node * node_, Evas_3D_Frustum_Mode key_) const
{
   Eina_Bool _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_camera_node_visible_get(camera_node_, node_, key_));
   return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
}

inline void eo_cxx::evas_3d_camera::projection_matrix_set(const Evas_Real * matrix_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_camera_projection_matrix_set(matrix_));
}

inline void eo_cxx::evas_3d_camera::projection_matrix_get(Evas_Real* matrix_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_camera_projection_matrix_get(matrix_));
}

inline void eo_cxx::evas_3d_camera::projection_perspective_set(Evas_Real fovy_, Evas_Real aspect_, Evas_Real dnear_, Evas_Real dfar_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_camera_projection_perspective_set(fovy_, aspect_, dnear_, dfar_));
}

inline void eo_cxx::evas_3d_camera::projection_frustum_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_camera_projection_frustum_set(left_, right_, bottom_, top_, dnear_, dfar_));
}

inline void eo_cxx::evas_3d_camera::projection_ortho_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_camera_projection_ortho_set(left_, right_, bottom_, top_, dnear_, dfar_));
}

inline bool eo_cxx::evas_3d_camera::node_visible_get(Evas_3D_Node * camera_node_, Evas_3D_Node * node_, Evas_3D_Frustum_Mode key_) const
{
   Eina_Bool _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_camera_node_visible_get(camera_node_, node_, key_));
   return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
}

inline ::eo_cxx::evas_3d_camera::operator ::evas_3d_camera() const
{
   return *static_cast<::evas_3d_camera const*>(static_cast<void const*>(this));
}

inline ::eo_cxx::evas_3d_camera::operator ::evas_3d_camera&()
{
   return *static_cast<::evas_3d_camera*>(static_cast<void*>(this));
}

inline ::eo_cxx::evas_3d_camera::operator ::evas_3d_camera const&() const
{
   return *static_cast<::evas_3d_camera const*>(static_cast<void const*>(this));
}

template <typename T>
void _evas_3d_camera_projection_matrix_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, const Evas_Real * matrix_)
{
   try
      {
         static_cast<T*>(self->this_)->projection_matrix_set(matrix_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void _evas_3d_camera_projection_matrix_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_Real* matrix_)
{
   try
      {
         static_cast<T*>(self->this_)->projection_matrix_get(matrix_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void _evas_3d_camera_projection_perspective_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_Real fovy_, Evas_Real aspect_, Evas_Real dnear_, Evas_Real dfar_)
{
   try
      {
         static_cast<T*>(self->this_)->projection_perspective_set(fovy_, aspect_, dnear_, dfar_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void _evas_3d_camera_projection_frustum_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_)
{
   try
      {
         static_cast<T*>(self->this_)->projection_frustum_set(left_, right_, bottom_, top_, dnear_, dfar_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void _evas_3d_camera_projection_ortho_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_)
{
   try
      {
         static_cast<T*>(self->this_)->projection_ortho_set(left_, right_, bottom_, top_, dnear_, dfar_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
bool _evas_3d_camera_node_visible_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_3D_Node * camera_node_, Evas_3D_Node * node_, Evas_3D_Frustum_Mode key_)
{
   bool _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->node_visible_get(camera_node_, node_, key_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::evas_3d_camera >
{
   template <typename T>
   struct type
         : virtual operations< ::evas_3d_object >::template type<T>
         , virtual operations< ::evas::common_interface >::template type<T>
   {
      virtual void projection_matrix_set(const Evas_Real * matrix_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_camera_projection_matrix_set(matrix_));
      }

      virtual void projection_matrix_get(Evas_Real* matrix_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_camera_projection_matrix_get(matrix_));
      }

      virtual void projection_perspective_set(Evas_Real fovy_, Evas_Real aspect_, Evas_Real dnear_, Evas_Real dfar_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_camera_projection_perspective_set(fovy_, aspect_, dnear_, dfar_));
      }

      virtual void projection_frustum_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_camera_projection_frustum_set(left_, right_, bottom_, top_, dnear_, dfar_));
      }

      virtual void projection_ortho_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_camera_projection_ortho_set(left_, right_, bottom_, top_, dnear_, dfar_));
      }

      virtual bool node_visible_get(Evas_3D_Node * camera_node_, Evas_3D_Node * node_, Evas_3D_Frustum_Mode key_)
      {
         Eina_Bool _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_3d_camera_node_visible_get(camera_node_, node_, key_));
            return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

   };
};


#ifdef EVAS_3D_CAMERA_PROTECTED
template<>
struct operation_description_class_size< ::evas_3d_camera >
{
   static constexpr int value = 6 + operation_description_class_size<::evas_3d_object >::value + operation_description_class_size<::evas::common_interface >::value;
};

#else
template<>
struct operation_description_class_size< ::evas_3d_camera >
{
   static constexpr int value = 6 + operation_description_class_size<::evas_3d_object >::value + operation_description_class_size<::evas::common_interface >::value;
};

#endif

template <typename T>
int initialize_operation_description(::efl::eo::detail::tag<::evas_3d_camera>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_evas_3d_camera_projection_matrix_set_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::evas_3d_camera_projection_matrix_set);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_evas_3d_camera_projection_matrix_get_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::evas_3d_camera_projection_matrix_get);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_evas_3d_camera_projection_perspective_set_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::evas_3d_camera_projection_perspective_set);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_evas_3d_camera_projection_frustum_set_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::evas_3d_camera_projection_frustum_set);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_evas_3d_camera_projection_ortho_set_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::evas_3d_camera_projection_ortho_set);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_evas_3d_camera_node_visible_get_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::evas_3d_camera_node_visible_get);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   initialize_operation_description<T>(::efl::eo::detail::tag<::evas_3d_object>(), &ops[operation_description_class_size< ::evas_3d_camera >::value]);
   initialize_operation_description<T>(::efl::eo::detail::tag<::evas::common_interface>(), &ops[operation_description_class_size< ::evas_3d_camera >::value + operation_description_class_size<::evas_3d_object>::value]);
   return 0;
}
inline Eo_Class const* get_eo_class(tag<::evas_3d_camera>)
{
   return (EVAS_3D_CAMERA_CLASS);
}

} } }

/// @endcond

